@@ -96,6 +96,7 @@ from ._jsii import *
 import aws_cdk.aws_apigateway
 import aws_cdk.aws_cognito
 import aws_cdk.aws_dynamodb
+import aws_cdk.aws_ec2
 import aws_cdk.aws_iam
 import aws_cdk.aws_kinesis
 import aws_cdk.aws_kinesisfirehose
@@ -103,6 +104,7 @@ import aws_cdk.aws_kms
 import aws_cdk.aws_lambda
 import aws_cdk.aws_lambda_event_sources
 import aws_cdk.aws_s3
+import aws_cdk.aws_sagemaker
 import aws_cdk.aws_sns
 import aws_cdk.aws_sqs
 
@@ -524,6 +526,7 @@ class BuildKinesisStreamProps:
     name_mapping={
         "existing_lambda_obj": "existingLambdaObj",
         "lambda_function_props": "lambdaFunctionProps",
+        "vpc": "vpc",
     },
 )
 class BuildLambdaFunctionProps:
@@ -532,10 +535,12 @@ class BuildLambdaFunctionProps:
         *,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
     ) -> None:
         """
         :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
+        :param vpc: A VPC where the Lambda function will access internal resources. Default: - none
         """
         if isinstance(lambda_function_props, dict):
             lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
@@ -544,6 +549,8 @@ class BuildLambdaFunctionProps:
             self._values["existing_lambda_obj"] = existing_lambda_obj
         if lambda_function_props is not None:
             self._values["lambda_function_props"] = lambda_function_props
+        if vpc is not None:
+            self._values["vpc"] = vpc
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
@@ -565,6 +572,15 @@ class BuildLambdaFunctionProps:
         result = self._values.get("lambda_function_props")
         return result
 
+    @builtins.property
+    def vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
+        """A VPC where the Lambda function will access internal resources.
+
+        :default: - none
+        """
+        result = self._values.get("vpc")
+        return result
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -740,6 +756,94 @@ class BuildS3BucketProps:
         )
 
 
+@jsii.data_type(
+    jsii_type="@aws-solutions-constructs/core.BuildSagemakerNotebookProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "role": "role",
+        "deploy_inside_vpc": "deployInsideVpc",
+        "existing_notebook_obj": "existingNotebookObj",
+        "sagemaker_notebook_props": "sagemakerNotebookProps",
+    },
+)
+class BuildSagemakerNotebookProps:
+    def __init__(
+        self,
+        *,
+        role: aws_cdk.aws_iam.Role,
+        deploy_inside_vpc: typing.Optional[builtins.bool] = None,
+        existing_notebook_obj: typing.Optional[aws_cdk.aws_sagemaker.CfnNotebookInstance] = None,
+        sagemaker_notebook_props: typing.Any = None,
+    ) -> None:
+        """
+        :param role: IAM Role Arn for SageMaker NoteBookInstance. Default: - None
+        :param deploy_inside_vpc: Optional user provided props to deploy inside vpc. Default: - true
+        :param existing_notebook_obj: An optional, Existing instance of notebook object. If this is set then the sagemakerNotebookProps is ignored Default: - None
+        :param sagemaker_notebook_props: Optional user provided props for CfnNotebookInstanceProps. Default: - Default props are used
+        """
+        self._values: typing.Dict[str, typing.Any] = {
+            "role": role,
+        }
+        if deploy_inside_vpc is not None:
+            self._values["deploy_inside_vpc"] = deploy_inside_vpc
+        if existing_notebook_obj is not None:
+            self._values["existing_notebook_obj"] = existing_notebook_obj
+        if sagemaker_notebook_props is not None:
+            self._values["sagemaker_notebook_props"] = sagemaker_notebook_props
+
+    @builtins.property
+    def role(self) -> aws_cdk.aws_iam.Role:
+        """IAM Role Arn for SageMaker NoteBookInstance.
+
+        :default: - None
+        """
+        result = self._values.get("role")
+        assert result is not None, "Required property 'role' is missing"
+        return result
+
+    @builtins.property
+    def deploy_inside_vpc(self) -> typing.Optional[builtins.bool]:
+        """Optional user provided props to deploy inside vpc.
+
+        :default: - true
+        """
+        result = self._values.get("deploy_inside_vpc")
+        return result
+
+    @builtins.property
+    def existing_notebook_obj(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_sagemaker.CfnNotebookInstance]:
+        """An optional, Existing instance of notebook object.
+
+        If this is set then the sagemakerNotebookProps is ignored
+
+        :default: - None
+        """
+        result = self._values.get("existing_notebook_obj")
+        return result
+
+    @builtins.property
+    def sagemaker_notebook_props(self) -> typing.Any:
+        """Optional user provided props for CfnNotebookInstanceProps.
+
+        :default: - Default props are used
+        """
+        result = self._values.get("sagemaker_notebook_props")
+        return result
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "BuildSagemakerNotebookProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.data_type(
     jsii_type="@aws-solutions-constructs/core.BuildTopicProps",
     jsii_struct_bases=[],
@@ -846,6 +950,84 @@ class BuildTopicProps:
         )
 
 
+@jsii.data_type(
+    jsii_type="@aws-solutions-constructs/core.BuildVpcProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "default_vpc_props": "defaultVpcProps",
+        "construct_vpc_props": "constructVpcProps",
+        "existing_vpc": "existingVpc",
+        "user_vpc_props": "userVpcProps",
+    },
+)
+class BuildVpcProps:
+    def __init__(
+        self,
+        *,
+        default_vpc_props: aws_cdk.aws_ec2.VpcProps,
+        construct_vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
+        existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+        user_vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
+    ) -> None:
+        """
+        :param default_vpc_props: One of the default VPC configurations available in vpc-defaults.
+        :param construct_vpc_props: Construct specified props that override both the default props and user props for the VPC.
+        :param existing_vpc: Existing instance of a VPC, if this is set then the all Props are ignored.
+        :param user_vpc_props: User provided props to override the default props for the VPC.
+        """
+        if isinstance(default_vpc_props, dict):
+            default_vpc_props = aws_cdk.aws_ec2.VpcProps(**default_vpc_props)
+        if isinstance(construct_vpc_props, dict):
+            construct_vpc_props = aws_cdk.aws_ec2.VpcProps(**construct_vpc_props)
+        if isinstance(user_vpc_props, dict):
+            user_vpc_props = aws_cdk.aws_ec2.VpcProps(**user_vpc_props)
+        self._values: typing.Dict[str, typing.Any] = {
+            "default_vpc_props": default_vpc_props,
+        }
+        if construct_vpc_props is not None:
+            self._values["construct_vpc_props"] = construct_vpc_props
+        if existing_vpc is not None:
+            self._values["existing_vpc"] = existing_vpc
+        if user_vpc_props is not None:
+            self._values["user_vpc_props"] = user_vpc_props
+
+    @builtins.property
+    def default_vpc_props(self) -> aws_cdk.aws_ec2.VpcProps:
+        """One of the default VPC configurations available in vpc-defaults."""
+        result = self._values.get("default_vpc_props")
+        assert result is not None, "Required property 'default_vpc_props' is missing"
+        return result
+
+    @builtins.property
+    def construct_vpc_props(self) -> typing.Optional[aws_cdk.aws_ec2.VpcProps]:
+        """Construct specified props that override both the default props and user props for the VPC."""
+        result = self._values.get("construct_vpc_props")
+        return result
+
+    @builtins.property
+    def existing_vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
+        """Existing instance of a VPC, if this is set then the all Props are ignored."""
+        result = self._values.get("existing_vpc")
+        return result
+
+    @builtins.property
+    def user_vpc_props(self) -> typing.Optional[aws_cdk.aws_ec2.VpcProps]:
+        """User provided props to override the default props for the VPC."""
+        result = self._values.get("user_vpc_props")
+        return result
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "BuildVpcProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.data_type(
     jsii_type="@aws-solutions-constructs/core.CfnDomainOptions",
     jsii_struct_bases=[],
@@ -1035,6 +1217,15 @@ class EventSourceProps:
         )
 
 
+@jsii.enum(jsii_type="@aws-solutions-constructs/core.ServiceEndpointTypes")
+class ServiceEndpointTypes(enum.Enum):
+    DYNAMODB = "DYNAMODB"
+    SNS = "SNS"
+    SQS = "SQS"
+    S3 = "S3"
+    STEPFUNCTIONS = "STEPFUNCTIONS"
+
+
 __all__ = [
     "AddProxyMethodToApiResourceInputParams",
     "BuildDeadLetterQueueProps",
@@ -1044,10 +1235,13 @@ __all__ = [
     "BuildLambdaFunctionProps",
     "BuildQueueProps",
     "BuildS3BucketProps",
+    "BuildSagemakerNotebookProps",
     "BuildTopicProps",
+    "BuildVpcProps",
     "CfnDomainOptions",
     "CognitoOptions",
     "EventSourceProps",
+    "ServiceEndpointTypes",
 ]
 
 publication.publish()
